==> hexo-theme-solitude-1.8.0.tgz: package/README_zh-tw.md <==
[简体中文](README.md)丨繁体中文丨[English](README_en.md)

<div align="center">
  
   <img src=".github/logo.svg" alt="Solitude logo" height="200">

  <h1>Hexo Theme Solitude</h1>

  一款優雅的 Hexo 主題，支援懶載入、PWA、Latex以及多種評論系統。

  主題由 [@张洪Heo](https://github.com/zhheo) 全權授權、設計！

![npm package](https://img.shields.io/npm/v/hexo-theme-solitude?color=blue&logo=npm)
![release](https://img.shields.io/github/package-json/v/valor-x/hexo-theme-solitude/master?color=%231ab1ad&label=release)
![license](https://img.shields.io/github/license/valor-x/hexo-theme-solitude?color=FF5531)
[![Stars](https://img.shields.io/github/stars/valor-x/hexo-theme-solitude)](https://github.com/valor-x/hexo-theme-solitude/stargazers)
[![GitHub all releases](https://img.shields.io/github/downloads/valor-x/hexo-theme-solitude/total)](https://github.com/valor-x/hexo-theme-solitude/releases/latest)

![hexo version](https://img.shields.io/badge/hexo-7.0.0+-blue?logo=hexo&logoColor=white)
![node version](https://img.shields.io/badge/node-14.0.0-white?logo=node.js&logoColor=white)

![Latex](https://img.shields.io/badge/latex-20B2AA?logo=Latex)
![Ads](https://img.shields.io/badge/Google_Ads-black?logo=googleads)
![algolia](https://img.shields.io/badge/algolia-457AFF?logo=algolia)

![cdnjs](https://img.shields.io/badge/cdnjs-orange?logo=Cloudflare&logoColor=white)
![A11y](https://img.shields.io/badge/A11y-green?logo=%C3%8Ele-de-France%20Mobilit%C3%A9s&logoColor=white)
![mermaid](https://img.shields.io/badge/mermaid-ff3670?logo=mermaid&logoColor=white)
[![pwa](https://img.shields.io/badge/pwa-red?logo=pwa)](https://developer.mozilla.org/en-US/docs/Web/Progressive_web_apps)

[![twiter](https://img.shields.io/badge/@efu__oo-gray?logo=x)](https://twitter.com/efu_oo)
[![TG](https://img.shields.io/badge/efuome-gray?logo=Telegram&logoColor=white)](https://t.me/solitudePro)

![JetBrains](https://img.shields.io/badge/jetbrains-support-black?logo=jetbrains)
![DuoLingo](https://img.shields.io/badge/duolingo-support-black?logo=duolingo&logoColor=white)

[![gitee](https://img.shields.io/badge/Gitee-red?logo=gitee)](https://gitee.com/nsjjd_w/hexo-theme-solitude)
[![gitlab](https://img.shields.io/badge/GitLab-blue?logo=gitlab)](https://gitlab.com/efu/hexo-theme-solitude)

[預覽](https://efu.me/) 丨  [文档](https://solitude-docs.efu.me/)

</div>

![Screenshot](.github/screenshot.png)

## 特性

- 頁面懶載入（Pjax）、圖片懶載入（LazyLoad）、離線應用（PWA） 
- 評論(Twikoo、Waline、Valine、Artalk)，支援雙評論
- 顯示切換（ColorMode） 
- 燈箱（medium-zoom、fancybox） 
- 數學公式（Latex） 
- 特色頁面：即刻短文、我的裝備、在線工具、音樂館、友鏈魚塘、相冊頁、豆瓣頁 
- 文章功能：AI 摘要、代碼高亮

## Todo

- [x] Waline 評論支援
- [ ] Tags plugin 外掛程式化
- [ ] 相冊頁重構（已移除，待重構）

## 應用

1. 使用 NPM 包進行安裝
      ```bash
      npm i hexo-theme-solitude
      ```
2. 應用主題
      ```yaml
      theme: solitude
      ```

前往 [文檔](https://solitude-docs.efu.me) 獲取更多資訊。

## 贊助者

<p align="center">
  <a href="https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg">
    <img src='https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg'/>
  </a>
</p>

## 版權

[MIT](./LICENSE) License &copy; 2023-至今 [Efu](https://github.com/efuo)

==> hexo-theme-solitude-1.8.5.tgz: package/README_zh-tw.md <==
[简体中文](README.md)丨繁体中文丨[English](README_en.md)

<div align="center">
  
   <img src=".github/logo.svg" alt="Solitude logo" height="200">

  <h1>Hexo Theme Solitude</h1>

  一款優雅的 Hexo 主題，支援懶載入、PWA、Latex以及多種評論系統。

  主題由 [@张洪Heo](https://github.com/zhheo) 全權授權、設計！

![npm package](https://img.shields.io/npm/v/hexo-theme-solitude?color=blue&logo=npm)
![release](https://img.shields.io/github/package-json/v/valor-x/hexo-theme-solitude/master?color=%231ab1ad&label=release)
![license](https://img.shields.io/github/license/valor-x/hexo-theme-solitude?color=FF5531)
[![Stars](https://img.shields.io/github/stars/valor-x/hexo-theme-solitude)](https://github.com/valor-x/hexo-theme-solitude/stargazers)
[![NPM all downloads](https://img.shields.io/npm/dy/hexo-theme-solitude?color=white)](https://www.npmjs.com/package/hexo-theme-solitude)

![hexo version](https://img.shields.io/badge/hexo-7.0.0+-blue?logo=hexo&logoColor=white)
![node version](https://img.shields.io/badge/node-14.0.0-white?logo=node.js&logoColor=white)

![Latex](https://img.shields.io/badge/latex-20B2AA?logo=Latex)
![Ads](https://img.shields.io/badge/Google_Ads-black?logo=googleads)
![algolia](https://img.shields.io/badge/algolia-457AFF?logo=algolia)

![cdnjs](https://img.shields.io/badge/cdnjs-orange?logo=Cloudflare&logoColor=white)
![A11y](https://img.shields.io/badge/A11y-green?logo=%C3%8Ele-de-France%20Mobilit%C3%A9s&logoColor=white)
![mermaid](https://img.shields.io/badge/mermaid-ff3670?logo=mermaid&logoColor=white)
[![pwa](https://img.shields.io/badge/pwa-red?logo=pwa)](https://developer.mozilla.org/en-US/docs/Web/Progressive_web_apps)

[![twiter](https://img.shields.io/badge/Twitter-gray?logo=x)](https://twitter.com/efu_oo)
[![TG](https://img.shields.io/badge/Telegram-gray?logo=Telegram&logoColor=white)](https://t.me/solitudePro)
[![Discord](https://img.shields.io/discord/1218118131428495430?label=Discord&logo=Discord&labelColor=white&color=black)](https://discord.gg/Y8VEvVgW)

![JetBrains](https://img.shields.io/badge/jetbrains-support-black?logo=jetbrains)
![DuoLingo](https://img.shields.io/badge/duolingo-support-black?logo=duolingo&logoColor=white)

[![gitee](https://img.shields.io/badge/Gitee-red?logo=gitee)](https://gitee.com/nsjjd_w/hexo-theme-solitude)
[![gitlab](https://img.shields.io/badge/GitLab-blue?logo=gitlab)](https://gitlab.com/efu/hexo-theme-solitude)

[預覽](https://efu.me/) 丨  [文档](https://solitude-docs.efu.me/)

</div>

![Screenshot](.github/screenshot.png)

## 特性

- 頁面懶載入（Pjax）、圖片懶載入（LazyLoad）、離線應用（PWA） 
- 評論(Twikoo、Waline、Valine、Artalk)，支援雙評論
- 晝夜切換（ColorMode） 
- 燈箱（medium-zoom、fancybox） 
- 數學公式（Latex） 
- 特色頁面：即刻短文、我的裝備、在線工具、音樂館、友鏈魚塘、相冊頁、豆瓣頁 
- 文章功能：AI 摘要、代碼高亮

## Todo

- [x] Artalk 評論
- [x] 雙評論
- [x] 相冊

## 應用

1. 使用 NPM 包進行安裝
      ```bash
      npm i hexo-theme-solitude
      ```
2. 應用主題
      ```yaml
      theme: solitude
      ```

前往 [文檔](https://solitude-docs.efu.me) 獲取更多資訊。

## 贊助者

<p align="center">
  <a href="https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg">
    <img src='https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg'/>
  </a>
</p>

## 版權

[MIT](./LICENSE) License &copy; 2023-至今 [Efu](https://github.com/efuo)
